aboutsummaryrefslogtreecommitdiffstats
path: root/test/unit/ajax.js
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/ajax.js')
-rw-r--r--test/unit/ajax.js62
1 files changed, 31 insertions, 31 deletions
diff --git a/test/unit/ajax.js b/test/unit/ajax.js
index 445f88aa3..39fb95be0 100644
--- a/test/unit/ajax.js
+++ b/test/unit/ajax.js
@@ -613,7 +613,7 @@ QUnit.module( "ajax", {
};
} );
- ajaxTest( "#15118 - jQuery.ajax() - function without jQuery.event", 1, function( assert ) {
+ ajaxTest( "trac-15118 - jQuery.ajax() - function without jQuery.event", 1, function( assert ) {
var holder;
return {
url: url( "mock.php?action=json" ),
@@ -629,7 +629,7 @@ QUnit.module( "ajax", {
};
} );
- ajaxTest( "#15160 - jQuery.ajax() - request manually aborted in ajaxSend", 3, function( assert ) {
+ ajaxTest( "trac-15160 - jQuery.ajax() - request manually aborted in ajaxSend", 3, function( assert ) {
return {
setup: function() {
jQuery( document ).on( "ajaxSend", function( e, jqXHR ) {
@@ -1895,7 +1895,7 @@ QUnit.module( "ajax", {
};
} );
- ajaxTest( "#2688 - jQuery.ajax() - beforeSend, cancel request", 2, function( assert ) {
+ ajaxTest( "trac-2688 - jQuery.ajax() - beforeSend, cancel request", 2, function( assert ) {
return {
create: function() {
return jQuery.ajax( {
@@ -1921,7 +1921,7 @@ QUnit.module( "ajax", {
};
} );
- ajaxTest( "#2806 - jQuery.ajax() - data option - evaluate function values", 1, function( assert ) {
+ ajaxTest( "trac-2806 - jQuery.ajax() - data option - evaluate function values", 1, function( assert ) {
return {
url: baseURL + "mock.php?action=echoQuery",
data: {
@@ -1935,7 +1935,7 @@ QUnit.module( "ajax", {
};
} );
- QUnit.test( "#7531 - jQuery.ajax() - Location object as url", function( assert ) {
+ QUnit.test( "trac-7531 - jQuery.ajax() - Location object as url", function( assert ) {
assert.expect( 1 );
var xhr,
@@ -1953,7 +1953,7 @@ QUnit.module( "ajax", {
} );
jQuery.each( [ " - Same Domain", " - Cross Domain" ], function( crossDomain, label ) {
- ajaxTest( "#7578 - jQuery.ajax() - JSONP - default for cache option" + label, 1, function( assert ) {
+ ajaxTest( "trac-7578 - jQuery.ajax() - JSONP - default for cache option" + label, 1, function( assert ) {
return {
url: baseURL + "mock.php?action=jsonp",
dataType: "jsonp",
@@ -1967,7 +1967,7 @@ QUnit.module( "ajax", {
} );
} );
- ajaxTest( "#8107 - jQuery.ajax() - multiple method signatures introduced in 1.5", 4, function( assert ) {
+ ajaxTest( "trac-8107 - jQuery.ajax() - multiple method signatures introduced in 1.5", 4, function( assert ) {
return [
{
create: function() {
@@ -2006,7 +2006,7 @@ QUnit.module( "ajax", {
} );
jQuery.each( [ " - Same Domain", " - Cross Domain" ], function( crossDomain, label ) {
- ajaxTest( "#8205 - jQuery.ajax() - JSONP - re-use callbacks name" + label, 4, function( assert ) {
+ ajaxTest( "trac-8205 - jQuery.ajax() - JSONP - re-use callbacks name" + label, 4, function( assert ) {
return {
url: baseURL + "mock.php?action=jsonp",
dataType: "jsonp",
@@ -2044,7 +2044,7 @@ QUnit.module( "ajax", {
} );
} );
- QUnit.test( "#9887 - jQuery.ajax() - Context with circular references (#9887)", function( assert ) {
+ QUnit.test( "trac-9887 - jQuery.ajax() - Context with circular references (trac-9887)", function( assert ) {
assert.expect( 2 );
var success = false,
@@ -2078,7 +2078,7 @@ QUnit.module( "ajax", {
};
}
- ajaxTest( "#10093 - jQuery.ajax() - falsy url " + title, 4, function( assert ) {
+ ajaxTest( "trac-10093 - jQuery.ajax() - falsy url " + title, 4, function( assert ) {
return [
request( assert, "", "empty string" ),
request( assert, false ),
@@ -2088,7 +2088,7 @@ QUnit.module( "ajax", {
} );
} );
- ajaxTest( "#11151 - jQuery.ajax() - parse error body", 2, function( assert ) {
+ ajaxTest( "trac-11151 - jQuery.ajax() - parse error body", 2, function( assert ) {
return {
url: url( "mock.php?action=error&json=1" ),
dataFilter: function( string ) {
@@ -2102,7 +2102,7 @@ QUnit.module( "ajax", {
};
} );
- ajaxTest( "#11426 - jQuery.ajax() - loading binary data shouldn't throw an exception in IE", 1, function( assert ) {
+ ajaxTest( "trac-11426 - jQuery.ajax() - loading binary data shouldn't throw an exception in IE", 1, function( assert ) {
return {
url: url( "1x1.jpg" ),
success: function( data ) {
@@ -2135,7 +2135,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
} );
}
- QUnit.test( "#11743 - jQuery.ajax() - script, throws exception", function( assert ) {
+ QUnit.test( "trac-11743 - jQuery.ajax() - script, throws exception", function( assert ) {
assert.expect( 1 );
var done = assert.async();
var onerror = window.onerror;
@@ -2170,7 +2170,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
}
ajaxTest(
- "#12004 - jQuery.ajax() - method is an alias of type - " +
+ "trac-12004 - jQuery.ajax() - method is an alias of type - " +
globalOption + " set globally", 3,
function( assert ) {
return {
@@ -2189,7 +2189,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
);
} );
- ajaxTest( "#13276 - jQuery.ajax() - compatibility between XML documents from ajax requests and parsed string", 1, function( assert ) {
+ ajaxTest( "trac-13276 - jQuery.ajax() - compatibility between XML documents from ajax requests and parsed string", 1, function( assert ) {
return {
url: baseURL + "dashboard.xml",
dataType: "xml",
@@ -2207,7 +2207,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
};
} );
- ajaxTest( "#13292 - jQuery.ajax() - converter is bypassed for 204 requests", 3, function( assert ) {
+ ajaxTest( "trac-13292 - jQuery.ajax() - converter is bypassed for 204 requests", 3, function( assert ) {
return {
url: baseURL + "mock.php?action=status&code=204&text=No+Content",
dataType: "testing",
@@ -2229,7 +2229,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
};
} );
- ajaxTest( "#13388 - jQuery.ajax() - responseXML", 3, function( assert ) {
+ ajaxTest( "trac-13388 - jQuery.ajax() - responseXML", 3, function( assert ) {
return {
url: url( "with_fries.xml" ),
dataType: "xml",
@@ -2241,7 +2241,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
};
} );
- ajaxTest( "#13922 - jQuery.ajax() - converter is bypassed for HEAD requests", 3, function( assert ) {
+ ajaxTest( "trac-13922 - jQuery.ajax() - converter is bypassed for HEAD requests", 3, function( assert ) {
return {
url: baseURL + "mock.php?action=json",
method: "HEAD",
@@ -2272,7 +2272,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
// Safari 13 did similar changes. The below check will catch them both.
if ( !/safari/i.test( navigator.userAgent ) ) {
testIframe(
- "#14379 - jQuery.ajax() on unload",
+ "trac-14379 - jQuery.ajax() on unload",
"ajax/onunload.html",
function( assert, jQuery, window, document, status ) {
assert.expect( 1 );
@@ -2281,7 +2281,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
);
}
- ajaxTest( "#14683 - jQuery.ajax() - Exceptions thrown synchronously by xhr.send should be caught", 4, function( assert ) {
+ ajaxTest( "trac-14683 - jQuery.ajax() - Exceptions thrown synchronously by xhr.send should be caught", 4, function( assert ) {
return [ {
url: baseURL + "mock.php?action=echoData",
method: "POST",
@@ -2504,7 +2504,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
//----------- jQuery.domManip()
- QUnit.test( "#11264 - jQuery.domManip() - no side effect because of ajaxSetup or global events", function( assert ) {
+ QUnit.test( "trac-11264 - jQuery.domManip() - no side effect because of ajaxSetup or global events", function( assert ) {
assert.expect( 1 );
jQuery.ajaxSetup( {
@@ -2521,7 +2521,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
} );
QUnit.test(
- "jQuery#load() - always use GET method even if it overrided through ajaxSetup (#11264)",
+ "jQuery#load() - always use GET method even if it overrided through ajaxSetup (trac-11264)",
function( assert ) {
assert.expect( 1 );
var done = assert.async();
@@ -2558,7 +2558,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
);
QUnit.test(
- "#11402 - jQuery.domManip() - script in comments are properly evaluated",
+ "trac-11402 - jQuery.domManip() - script in comments are properly evaluated",
function( assert ) {
assert.expect( 2 );
jQuery( "#qunit-fixture" ).load( baseURL + "cleanScript.html", assert.async() );
@@ -2581,7 +2581,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
} );
} );
- QUnit.test( "#8277 - jQuery.get( String, Function ) - data in ajaxSettings", function( assert ) {
+ QUnit.test( "trac-8277 - jQuery.get( String, Function ) - data in ajaxSettings", function( assert ) {
assert.expect( 1 );
var done = assert.async();
jQuery.ajaxSetup( {
@@ -2672,7 +2672,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
jQuery.getScript( url( "mock.php?action=testbar" ) ).done( assert.async() );
} );
- QUnit.test( "#8082 - jQuery.getScript( String, Function ) - source as responseText", function( assert ) {
+ QUnit.test( "trac-8082 - jQuery.getScript( String, Function ) - source as responseText", function( assert ) {
assert.expect( 2 );
var done = assert.async();
@@ -2759,7 +2759,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
} );
} );
// Selector should be trimmed to avoid leading spaces (#14773)
QUnit.test( "jQuery.fn.load( URL_SELECTOR with spaces )", function( assert ) {
assert.expect( 1 );
var done = assert.async();
@@ -2769,9 +2769,9 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
} );
} );
- // Selector should be trimmed to avoid leading spaces (#14773)
- // Selector should include any valid non-HTML whitespace (#3003)
- QUnit.test( "jQuery.fn.load( URL_SELECTOR with non-HTML whitespace(#3003) )", function( assert ) {
+ // Selector should be trimmed to avoid leading spaces (trac-14773)
+ // Selector should include any valid non-HTML whitespace (trac-3003)
+ QUnit.test( "jQuery.fn.load( URL_SELECTOR with non-HTML whitespace(trac-3003) )", function( assert ) {
assert.expect( 1 );
var done = assert.async();
jQuery( "#first" ).load( baseURL + "test3.html #whitespace\\\\xA0 ", function() {
@@ -2902,7 +2902,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
).always( done );
} );
- QUnit.test( "#2046 - jQuery.fn.load( String, Function ) with ajaxSetup on dataType json", function( assert ) {
+ QUnit.test( "trac-2046 - jQuery.fn.load( String, Function ) with ajaxSetup on dataType json", function( assert ) {
assert.expect( 1 );
var done = assert.async();
@@ -2917,7 +2917,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
jQuery( "#first" ).load( baseURL + "test3.html" );
} );
- QUnit.test( "#10524 - jQuery.fn.load() - data specified in ajaxSettings is merged in", function( assert ) {
+ QUnit.test( "trac-10524 - jQuery.fn.load() - data specified in ajaxSettings is merged in", function( assert ) {
assert.expect( 1 );
var done = assert.async();
@@ -2759,7 +2759,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
} );
} );
- // Selector should be trimmed to avoid leading spaces (#14773)
+ // Selector should be trimmed to avoid leading spaces (trac-14773)
QUnit.test( "jQuery.fn.load( URL_SELECTOR with spaces )", function( assert ) {
assert.expect( 1 );